summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:36 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 10:00:36 -0600
commit1fffbdafa12271a1a635caf46777fb8acfb6f31b (patch)
tree707785bd058e254fd865ca30ed35f37f206aebbc /quanta/parts/kafka
parent2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076 (diff)
downloadtdewebdev-1fffbdafa12271a1a635caf46777fb8acfb6f31b.tar.gz
tdewebdev-1fffbdafa12271a1a635caf46777fb8acfb6f31b.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 2b0e1de2ffcca7bb93f1fd8ddd32f74041d0d076.
Diffstat (limited to 'quanta/parts/kafka')
-rw-r--r--quanta/parts/kafka/domtreeview.cpp4
-rw-r--r--quanta/parts/kafka/htmldocumentpropertiesui.ui14
-rw-r--r--quanta/parts/kafka/kafkacommon.cpp6
-rw-r--r--quanta/parts/kafka/kafkacommon.h10
-rw-r--r--quanta/parts/kafka/kafkadragobject.cpp6
-rw-r--r--quanta/parts/kafka/kafkadragobject.h2
-rw-r--r--quanta/parts/kafka/kafkahtmlpart.cpp4
-rw-r--r--quanta/parts/kafka/kafkahtmlpart.h2
-rw-r--r--quanta/parts/kafka/kafkasyncoptionsui.ui6
-rw-r--r--quanta/parts/kafka/undoredo.cpp4
-rw-r--r--quanta/parts/kafka/undoredo.h12
-rw-r--r--quanta/parts/kafka/wkafkapart.cpp10
12 files changed, 40 insertions, 40 deletions
diff --git a/quanta/parts/kafka/domtreeview.cpp b/quanta/parts/kafka/domtreeview.cpp
index 1fe4505a..c8d4c6c9 100644
--- a/quanta/parts/kafka/domtreeview.cpp
+++ b/quanta/parts/kafka/domtreeview.cpp
@@ -22,7 +22,7 @@
#include <khtml_part.h>
#include <klocale.h>
#include <tqstring.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <dom/dom_text.h>
#include "domtreeview.moc"
@@ -140,7 +140,7 @@ void DOMTreeView::slotItemClicked(TQListViewItem *cur_item)
KafkaDOMTreeDialog::KafkaDOMTreeDialog(TQWidget *parent, KHTMLPart *part, const char* name, bool modal, WFlags fl )
: TQDialog(parent, name, modal, fl)
{
- setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)1, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)1, 0, 0, sizePolicy().hasHeightForWidth() ) );
DialogLayout = new TQGridLayout( this, 1, 1, 11, 6, "DialogLayout");
domview = new DOMTreeView(this, part, name);
domview->setTitle(i18n( "Debugging KafkaWidget DOM Tree " ));
diff --git a/quanta/parts/kafka/htmldocumentpropertiesui.ui b/quanta/parts/kafka/htmldocumentpropertiesui.ui
index c826dd73..de2293dd 100644
--- a/quanta/parts/kafka/htmldocumentpropertiesui.ui
+++ b/quanta/parts/kafka/htmldocumentpropertiesui.ui
@@ -42,7 +42,7 @@
<property name="name">
<cstring>listView1</cstring>
</property>
- <property name="maximumSize">
+ <property name="tqmaximumSize">
<size>
<width>0</width>
<height>0</height>
@@ -137,7 +137,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>86</height>
@@ -170,7 +170,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>84</height>
@@ -187,7 +187,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>226</width>
<height>21</height>
@@ -220,7 +220,7 @@
<property name="sizeType">
<enum>Preferred</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>41</width>
<height>20</height>
@@ -374,7 +374,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>250</width>
<height>0</height>
@@ -393,7 +393,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="minimumSize">
+ <property name="tqminimumSize">
<size>
<width>250</width>
<height>0</height>
diff --git a/quanta/parts/kafka/kafkacommon.cpp b/quanta/parts/kafka/kafkacommon.cpp
index 32f5f43c..5d7e8cdb 100644
--- a/quanta/parts/kafka/kafkacommon.cpp
+++ b/quanta/parts/kafka/kafkacommon.cpp
@@ -999,7 +999,7 @@ Node* kafkaCommon::insertNode(Node *node, Node* parentNode, Node* nextSibling,
if(!node)
return 0L;
- //Reset the listviews items pointers for node and its children
+ //Reset the listviews items pointers for node and its tqchildren
n = node;
b = false;
while(n)
@@ -1100,7 +1100,7 @@ Node* kafkaCommon::insertNode(Node *node, Node* parentNode, Node* nextSibling, N
if(!node)
return 0L;
- //Reset the listviews items pointers for node and its children
+ //Reset the listviews items pointers for node and its tqchildren
n = node;
b = false;
while(n)
@@ -2253,7 +2253,7 @@ Node* kafkaCommon::extractNode(Node *node, NodeModifsSet *modifs, bool extractCh
modif->setType(NodeModif::NodeRemoved);
modif->setLocation(getLocation(node));
- //log the children move if we don't extract the children
+ //log the tqchildren move if we don't extract the tqchildren
if(!extractChildren)
{
location = getLocation(node);
diff --git a/quanta/parts/kafka/kafkacommon.h b/quanta/parts/kafka/kafkacommon.h
index 6322919d..80a82122 100644
--- a/quanta/parts/kafka/kafkacommon.h
+++ b/quanta/parts/kafka/kafkacommon.h
@@ -522,8 +522,8 @@ public:
* This mean that the undo/redo system will delete it when necessary so don't reuse it!!!!
* @param node The node to delete.
* @param modifs The changes made are logged into modifs.
- * @param extractChilds If we extract or move up the children. WARNING: it don't check
- * if the children of node are legal childs of the parent of node.
+ * @param extractChilds If we extract or move up the tqchildren. WARNING: it don't check
+ * if the tqchildren of node are legal childs of the parent of node.
* @param removeClosingTag Extract the closingTag if node isn't single and is Tag::XmlTag.
* TODO: @param removeEmbeddedTags Specifies if we delete the embedded Nodes e.g.
* <a href="<? boo ?>" > : the PHP block is an embedded block.
@@ -588,7 +588,7 @@ public:
/**
* An enumeration of all the possible return states of DTDExtractNode
*/
- enum extractNodeStatus
+ enum extractNodetqStatus
{
//The node to extract was not found.
nothingExtracted = 0,
@@ -619,7 +619,7 @@ public:
* @param cursorOffset The offset of the cursor inside cursorNode.
* </TEMPORARY>
* @param modifs The usual modifs to log the modifications made for the undo/redo system.
- * @return Returns a kafkaCommon::extractNodeStatus.
+ * @return Returns a kafkaCommon::extractNodetqStatus.
*/
static int DTDExtractNode(const TQString &nodeName, Document *doc, Node *startNode,
int startOffset, Node *endNode, int endOffset, Node **cursorNode, long &cursorOffset,
@@ -986,7 +986,7 @@ public:
/**
* Returns the position of the child domNode.
* @param domNode This is the DOM::Node we want the position.
- * @return Returns the position of domNode inside domNode's parent's children or -1 if not found.
+ * @return Returns the position of domNode inside domNode's parent's tqchildren or -1 if not found.
*/
static int childPosition(DOM::Node domNode);
diff --git a/quanta/parts/kafka/kafkadragobject.cpp b/quanta/parts/kafka/kafkadragobject.cpp
index 5a614b23..40aeac9a 100644
--- a/quanta/parts/kafka/kafkadragobject.cpp
+++ b/quanta/parts/kafka/kafkadragobject.cpp
@@ -18,7 +18,7 @@
#include <kdebug.h>
#include <tqdom.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include "kafkadragobject.h"
#include "node.h"
@@ -51,7 +51,7 @@ KafkaDragObject::KafkaDragObject(Node const* item, TQWidget* dragSource, const c
KafkaDragObject::~KafkaDragObject()
{}
-TQByteArray KafkaDragObject::encodedData(const char* mimetype) const
+TQByteArray KafkaDragObject::tqencodedData(const char* mimetype) const
{
if(m_mimetype == mimetype)
return m_array;
@@ -74,7 +74,7 @@ bool KafkaDragObject::decode(TQMimeSource* e, Node* node)
if(!node || !e->provides(m_mimetype))
return false;
- TQByteArray data = e->encodedData(m_mimetype);
+ TQByteArray data = e->tqencodedData(m_mimetype);
//kdDebug(25001) << TQString(data) << endl;
TQDomDocument doc;
doc.setContent(data, false);
diff --git a/quanta/parts/kafka/kafkadragobject.h b/quanta/parts/kafka/kafkadragobject.h
index cc371b45..65cf24a5 100644
--- a/quanta/parts/kafka/kafkadragobject.h
+++ b/quanta/parts/kafka/kafkadragobject.h
@@ -35,7 +35,7 @@ public:
KafkaDragObject(Node const* item, TQWidget* dragSource = 0, const char* name = 0);
~KafkaDragObject();
- TQByteArray encodedData(const char* c) const;
+ TQByteArray tqencodedData(const char* c) const;
Node const* getItem() const;
static bool canDecode(TQMimeSource*);
diff --git a/quanta/parts/kafka/kafkahtmlpart.cpp b/quanta/parts/kafka/kafkahtmlpart.cpp
index af44e908..52195d83 100644
--- a/quanta/parts/kafka/kafkahtmlpart.cpp
+++ b/quanta/parts/kafka/kafkahtmlpart.cpp
@@ -18,9 +18,9 @@
#include <tqfile.h>
#include <tqpainter.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqstringlist.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqmainwindow.h>
#include <tqtimer.h>
#include <tqtooltip.h>
diff --git a/quanta/parts/kafka/kafkahtmlpart.h b/quanta/parts/kafka/kafkahtmlpart.h
index 3f3e3c83..17c25ddf 100644
--- a/quanta/parts/kafka/kafkahtmlpart.h
+++ b/quanta/parts/kafka/kafkahtmlpart.h
@@ -113,7 +113,7 @@ public:
/** --------------- DOM::Node modifications -------------------------- */
/**
- * It will move DOM::Nodes from startNode to endNode as children of newParent. It does NOT check
+ * It will move DOM::Nodes from startNode to endNode as tqchildren of newParent. It does NOT check
* if the move is valid, so it may crash. Please check before with kafkaCommon::parentSupports().
* @param newParent The new parent of the DOM::Nodes.
* @param startNode The first node to move.
diff --git a/quanta/parts/kafka/kafkasyncoptionsui.ui b/quanta/parts/kafka/kafkasyncoptionsui.ui
index d82aa14f..509ab551 100644
--- a/quanta/parts/kafka/kafkasyncoptionsui.ui
+++ b/quanta/parts/kafka/kafkasyncoptionsui.ui
@@ -51,7 +51,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>120</width>
<height>31</height>
@@ -119,7 +119,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>27</width>
<height>31</height>
@@ -175,7 +175,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>21</width>
<height>167</height>
diff --git a/quanta/parts/kafka/undoredo.cpp b/quanta/parts/kafka/undoredo.cpp
index d21129cd..1e177b0c 100644
--- a/quanta/parts/kafka/undoredo.cpp
+++ b/quanta/parts/kafka/undoredo.cpp
@@ -51,7 +51,7 @@ NodeModif::NodeModif()
m_type = -1;
m_node = 0L;
m_tag = 0L;
- m_childrenMovedUp = 0;
+ m_tqchildrenMovedUp = 0;
m_neighboursMovedDown = 0;
}
@@ -1477,7 +1477,7 @@ void undoRedo::debugOutput()
" - contents: " << (*it2)->tag()->tagStr() << endl;
if(((*it2)->type() == NodeModif::NodeRemoved && !afterEditorIt) ||
((*it2)->type() == NodeModif::NodeAdded && afterEditorIt))
- kdDebug(24000)<< "==== ChildsNumber1 : " << (*it2)->childrenMovedUp() <<
+ kdDebug(24000)<< "==== ChildsNumber1 : " << (*it2)->tqchildrenMovedUp() <<
" - ChildsNumber2 : " << (*it2)->neighboursMovedDown() << endl;
}
kdDebug(24000)<< "== End Node Modifications set #" << i << endl;
diff --git a/quanta/parts/kafka/wkafkapart.cpp b/quanta/parts/kafka/wkafkapart.cpp
index ee56255d..f51327a7 100644
--- a/quanta/parts/kafka/wkafkapart.cpp
+++ b/quanta/parts/kafka/wkafkapart.cpp
@@ -34,9 +34,9 @@
#include <tqregexp.h>
#include <tqfile.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdatetime.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqptrvector.h>
#include "document.h"
@@ -2328,7 +2328,7 @@ void KafkaDocument::slotCut(Node* startNode, int startOffset, Node* endNode, int
drag_object->addDragObject(node_drag);
drag_object->addDragObject(text_drag);
- TQApplication::clipboard()->setData(drag_object);
+ TQApplication::tqclipboard()->setData(drag_object);
#ifdef LIGHT_DEBUG
kafkaCommon::coutTree(subtree_root, 3);
#endif
@@ -2365,7 +2365,7 @@ void KafkaDocument::slotCopy(Node* startNode, int startOffset, Node* endNode, in
drag_object->addDragObject(node_drag);
drag_object->addDragObject(text_drag);
- TQApplication::clipboard()->setData(drag_object);
+ TQApplication::tqclipboard()->setData(drag_object);
// FIXME delete the subtree
#ifdef LIGHT_DEBUG
kafkaCommon::coutTree(subtree_root, 3);
@@ -2375,7 +2375,7 @@ void KafkaDocument::slotCopy(Node* startNode, int startOffset, Node* endNode, in
void KafkaDocument::slotPaste()
{
- TQClipboard *cb = TQApplication::clipboard();
+ TQClipboard *cb = TQApplication::tqclipboard();
TQMimeSource* e = cb->data();
Node* node = new Node(0);
diff --git a/quanta/parts/kafka/undoredo.h b/quanta/parts/kafka/undoredo.h
index 6464c46d..6280a67f 100644
--- a/quanta/parts/kafka/undoredo.h
+++ b/quanta/parts/kafka/undoredo.h
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
* For non-XmlEnd Node deletion without its children.
* @param childrenNumber The number of children which are moved up
* at the location where was the deleted Node.
*/
- void setChildrenMovedUp(int childrenNumber) {m_childrenMovedUp = childrenNumber;}
+ void setChildrenMovedUp(int tqchildrenNumber) {m_tqchildrenMovedUp = tqchildrenNumber;}
/**
* TODO:REMOVE
* @return Returns the number of childs which were moved up.
*/
- int childrenMovedUp() {return m_childrenMovedUp;}
+ int tqchildrenMovedUp() {return m_tqchildrenMovedUp;}
/**
* TODO:REMOVE
@@ -139,7 +139,7 @@ public:
NodeTreeRemoved,
//Moving a Node from one location to another. Implemented.
NodeMoved,
//Moving a Node and its children from one location to another.
NodeAndChildsMoved
};
@@ -148,7 +148,7 @@ private:
TQValueList<int> m_location, m_finalLocation;
Node *m_node;
Tag *m_tag;
- int m_childrenMovedUp;
+ int m_tqchildrenMovedUp;
int m_neighboursMovedDown;
};
@@ -95,17 +95,17 @@ public:
/**
* TODO:REMOVE
- * For non-XmlEnd Node deletion without its children.
- * @param childrenNumber The number of children which are moved up
+ * For non-XmlEnd Node deletion without its tqchildren.
+ * @param tqchildrenNumber The number of tqchildren which are moved up
* at the location where was the deleted Node.
*/
@@ -139,7 +139,7 @@ public:
//Moving a Node from one location to another. Implemented.
NodeMoved,
- //Moving a Node and its children from one location to another.
+ //Moving a Node and its tqchildren from one location to another.
NodeAndChildsMoved
};